# Byte modular assistant

## Description
This repository implements a modular personal assistant featuring pip installation and CPU based inference as a way to promote a system that is easy to setup, have low hardware requirements and is privacy aware.

## Objective

The aim of this project is to allow tinkerers to easily develop customizable personal assistants based on local LLM's without complicated dependency setup and in-depth knowedge of LLM's and interprocess communication.

## Developer notes

### Comming soon:
- Software licence
- Documentation
- Customization tutorials
- Pypi installation
- Binary package

### TODO
- Config builder tool

Most of things metioned here will be released as soon as the project enters its alpha stage.

WARNING: This repository is in a pre-alpha stage, many of the interfaces you see implemented now will change as the project matures.

## Acknowledgements

I much apriciate ArjanCodes for sharing his clear and concise implementation of a plugin system in which the core of this repository is based. The original implementation can be found [here](https://github.com/ArjanCodes/2021-plugin-architecture).
